@@ -250,6 +250,7 @@ class Engine:
         :type data: Optional[dict], optional
         """
         node = self.runtime.get_node(node_id)
+        escape_render_keys = data.pop("_escape_render_keys", []) if data else []
 
         if not node.can_retry:
             raise InvalidOperationError("can not retry node({}) with can_retry({})".format(node_id, node.can_retry))
@@ -263,7 +264,10 @@ class Engine:
         if data is not None:
             self.runtime.set_data_inputs(
                 node_id,
-                {k: DataInput(need_render=True, value=v) for k, v in data.items()},
+                {
+                    k: DataInput(need_render=False if k in escape_render_keys else True, value=v)
+                    for k, v in data.items()
+                },
             )
 
         self._add_history(node_id, state)
@@ -750,10 +754,11 @@ class Engine:
                             loop = node_state.loop + 1
                             inner_loop = node_state.inner_loop + 1
                             reset_mark_bit = True
-
-                        # 重入前记录历史
-                        if node_state.name == states.FINISHED:
+                            # 重入前记录历史
                             self._add_history(node_id=current_node_id, state=node_state)
+                        else:
+                            loop = node_state.loop
+                            inner_loop = node_state.inner_loop
                 else:
                     interrupter.check_and_set(
                         ExecuteKeyPoint.SET_NODE_RUNNING_PRE_CHECK_DONE, state_already_exist=False
