@@ -38,7 +38,7 @@ from .models import (
 
 # plugin interface
 
-__version__ = "7.0.0"
+__version__ = "7.1.0"
 
 
 def version():
@@ -1204,6 +1204,17 @@ class DataMixin:
         :rtype: Data
         """
 
+    @abstractmethod
+    def get_batch_data(self, node_ids: List[str]) -> Dict[str, Data]:
+        """
+        批量获取节点数据对象
+
+        :param node_ids: 节点 ID 列表
+        :type node_ids: List[str]
+        :return: 节点数据对象字典 node_id: Data
+        :rtype: dict
+        """
+
     @abstractmethod
     def get_data_inputs(self, node_id: str) -> Dict[str, DataInput]:
         """
